==> jc-1.4.0.tar.gz: jas/LongCP.h <==
// public class jas.LongCP

// class file dependencies
// @dep_class c0e5264359137f3 jas_CP
// @dep_class 1bd4c306dbd811aa jas_LongCP
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header jas_CP

#include "jas/CP.h"

#ifndef _JC_jas_LongCP_H_
#define _JC_jas_LongCP_H_

// Forward structure declarations
struct _jc_jas_ClassEnv$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_LongCP$sub_refs	_jc_jas_LongCP$sub_refs;
typedef struct _jc_jas_LongCP$sub_nonrefs	_jc_jas_LongCP$sub_nonrefs;
typedef struct _jc_jas_LongCP$refs	_jc_jas_LongCP$refs;
typedef struct _jc_jas_LongCP$nonrefs	_jc_jas_LongCP$nonrefs;
typedef struct _jc_jas_LongCP$object	_jc_jas_LongCP$object;

typedef const struct _jc_jas_LongCP$vmethods	_jc_jas_LongCP$vmethods;
typedef const struct _jc_jas_LongCP$vtable	_jc_jas_LongCP$vtable;
typedef const struct _jc_jas_LongCP$vtype	_jc_jas_LongCP$vtype;

// Constructors
extern void _jc_jas_LongCP$method$_init$8de6a0a3bec04d2a(_jc_env *, struct _jc_jas_LongCP$object *, jlong);

// Virtual methods
extern void _jc_jas_LongCP$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_LongCP$object *, struct _jc_jas_ClassEnv$object *);
extern void _jc_jas_LongCP$method$write$c5719140f8114b75(_jc_env *, struct _jc_jas_LongCP$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_jas_LongCP$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_LongCP$method_info$write$c5719140f8114b75;

// Virtual methods structure
struct _jc_jas_LongCP$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_LongCP$object *, struct _jc_jas_ClassEnv$object *);
	void	(*write$c5719140f8114b75)(_jc_env *, struct _jc_jas_LongCP$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *);
};

// Vtable
struct _jc_jas_LongCP$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_CP$vmethods	jas_CP;
	_jc_jas_LongCP$vmethods	jas_LongCP;
};

// Vtype
struct _jc_jas_LongCP$vtype {
	_jc_type			type;
	_jc_jas_LongCP$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_LongCP$sub_refs {
};

// Reference instance fields (object)
struct _jc_jas_LongCP$refs {
    _jc_jas_LongCP$sub_refs	jas_LongCP;
    _jc_jas_CP$sub_refs	jas_CP;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_LongCP$sub_nonrefs {
	jlong	val;
};

// Non-reference instance fields (object)
struct _jc_jas_LongCP$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_CP$sub_nonrefs	jas_CP;
    _jc_jas_LongCP$sub_nonrefs	jas_LongCP;
};

// Object instance structure
struct _jc_jas_LongCP$object {
	_jc_jas_LongCP$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_LongCP$vtype	*vtype;
	_jc_jas_LongCP$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_LongCP$vtype _jc_jas_LongCP$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_LongCP, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_LongCP$class_object;

#endif	/* _JC_jas_LongCP_H_ */

==> jc-1.4.6.tar.gz: jas/LongCP.h <==
// public class jas.LongCP

// class file dependencies
// @dep_class c0e5264359137f3 jas_CP
// @dep_class 1bd4c306dbd811aa jas_LongCP
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header jas_CP

#include "jas/CP.h"

#ifndef _JC_jas_LongCP_H_
#define _JC_jas_LongCP_H_

// Forward structure declarations
struct _jc_jas_ClassEnv$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_LongCP$sub_refs	_jc_jas_LongCP$sub_refs;
typedef struct _jc_jas_LongCP$sub_nonrefs	_jc_jas_LongCP$sub_nonrefs;
typedef struct _jc_jas_LongCP$refs	_jc_jas_LongCP$refs;
typedef struct _jc_jas_LongCP$nonrefs	_jc_jas_LongCP$nonrefs;
typedef struct _jc_jas_LongCP$object	_jc_jas_LongCP$object;

typedef const struct _jc_jas_LongCP$vmethods	_jc_jas_LongCP$vmethods;
typedef const struct _jc_jas_LongCP$vtable	_jc_jas_LongCP$vtable;
typedef const struct _jc_jas_LongCP$vtype	_jc_jas_LongCP$vtype;

// Constructors
extern void _jc_jas_LongCP$method$_init$8de6a0a3bec04d2a(_jc_env *, struct _jc_jas_LongCP$object *, jlong) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_jas_LongCP$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_LongCP$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
extern void _jc_jas_LongCP$method$write$c5719140f8114b75(_jc_env *, struct _jc_jas_LongCP$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_jas_LongCP$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_LongCP$method_info$write$c5719140f8114b75;

// Virtual methods structure
struct _jc_jas_LongCP$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_LongCP$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
	void	(*write$c5719140f8114b75)(_jc_env *, struct _jc_jas_LongCP$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_jas_LongCP$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_CP$vmethods	jas_CP;
	_jc_jas_LongCP$vmethods	jas_LongCP;
};

// Vtype
struct _jc_jas_LongCP$vtype {
	_jc_type			type;
	_jc_jas_LongCP$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_LongCP$sub_refs {
};

// Reference instance fields (object)
struct _jc_jas_LongCP$refs {
    _jc_jas_LongCP$sub_refs	jas_LongCP;
    _jc_jas_CP$sub_refs	jas_CP;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_LongCP$sub_nonrefs {
	jlong	val;
};

// Non-reference instance fields (object)
struct _jc_jas_LongCP$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_CP$sub_nonrefs	jas_CP;
    _jc_jas_LongCP$sub_nonrefs	jas_LongCP;
};

// Object instance structure
struct _jc_jas_LongCP$object {
	_jc_jas_LongCP$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_LongCP$vtype	*vtype;
	_jc_jas_LongCP$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_LongCP$vtype _jc_jas_LongCP$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_LongCP, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_LongCP$class_object;

#endif	/* _JC_jas_LongCP_H_ */
